Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(191)

Unified Diff: editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameLocalVariableProcessorTest.java

Issue 12340077: Initial binding of RenameRefactoring service to Eclipse. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameLocalVariableProcessorTest.java
diff --git a/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameLocalVariableProcessorTest.java b/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameLocalVariableProcessorTest.java
index c1019e79b683853a239c2a6ca692ca54c2cc8995..edae705f10f4cefa5b968bbe188b14a66d3e1b8f 100644
--- a/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameLocalVariableProcessorTest.java
+++ b/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameLocalVariableProcessorTest.java
@@ -16,7 +16,7 @@ package com.google.dart.tools.ui.refactoring;
import com.google.dart.tools.core.internal.model.SourceRangeImpl;
import com.google.dart.tools.core.model.DartVariableDeclaration;
import com.google.dart.tools.internal.corext.refactoring.rename.RenameLocalVariableProcessor;
-import com.google.dart.tools.ui.internal.refactoring.RenameSupport;
+import com.google.dart.tools.ui.internal.refactoring.RenameSupport_OLD;
import org.eclipse.ltk.core.refactoring.RefactoringStatus;
import org.eclipse.ui.IWorkbenchWindow;
@@ -33,11 +33,11 @@ import java.lang.reflect.Proxy;
*/
public final class RenameLocalVariableProcessorTest extends RefactoringTest {
/**
* Uses {@link RenameSupport} to rename {@link DartVariableDeclaration}.
*/
private static void renameLocalVariable(DartVariableDeclaration variable, String newName)
throws Exception {
- RenameSupport renameSupport = RenameSupport.create(variable, newName);
+ RenameSupport_OLD renameSupport = RenameSupport_OLD.create(variable, newName);
IWorkbenchWindow workbenchWindow = PlatformUI.getWorkbench().getActiveWorkbenchWindow();
renameSupport.perform(workbenchWindow.getShell(), workbenchWindow);
}
@@ -33,11 +33,11 @@ import java.lang.reflect.Proxy;
public final class RenameLocalVariableProcessorTest extends RefactoringTest {
/**
- * Uses {@link RenameSupport} to rename {@link DartVariableDeclaration}.
+ * Uses {@link RenameSupport_OLD} to rename {@link DartVariableDeclaration}.
*/
private static void renameLocalVariable(DartVariableDeclaration variable, String newName)

Powered by Google App Engine
This is Rietveld 408576698